@@ -103,6 +103,9 @@ function(vars,                                   # character vector of variable
     ## Abort if no variables exist at this point
     ModuleStopIfNoVarsLeft(vars)
 
+    ## Get the missing percentage for each variable (no strata).
+    percentMissing <- ModulePercentMissing(data[vars])
+
     ## Extract necessary variables
     dat <- data[c(vars)]
 
@@ -249,7 +252,8 @@ function(vars,                                   # character vector of variable
     ## Give additional attributes
     attributes(result) <- c(attributes(result),
                             list(pValues = pValues),
-                            list(smd     = smds))
+                            list(smd     = smds),
+                            list(percentMissing = percentMissing))
 
     ## Return
     return(result)
